@@ -28,14 +28,8 @@ def get_netbox_docker_version_tag(netbox_version):
     """
     major, minor = netbox_version.major, netbox_version.minor
 
-    if (major, minor) == (2, 10):
-        tag = "1.0.1"
-    elif (major, minor) == (2, 9):
-        tag = "0.26.2"
-    elif (major, minor) == (2, 8):
-        tag = "0.24.1"
-    elif (major, minor) == (2, 7):
-        tag = "0.24.0"
+    if (major, minor) == (3, 3):
+        tag = "2.2.0"
     else:
         raise NotImplementedError(
             "Version %s is not currently supported" % netbox_version
@@ -84,6 +78,7 @@ def netbox_docker_repo_dirpaths(pytestconfig, git_toplevel):
     netbox_versions_by_repo_dirpaths = {}
     for netbox_version in pytestconfig.option.netbox_versions:
         repo_version_tag = get_netbox_docker_version_tag(netbox_version=netbox_version)
+        print("top: ", git_toplevel)
         repo_fpath = os.path.join(
             git_toplevel, ".netbox-docker-%s" % str(repo_version_tag)
         )
@@ -231,11 +226,12 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                 DOCKER_PROJECT_PREFIX,
                 docker_netbox_version,
             )
-            compose_data["networks"] = {
-                docker_network_name: {
-                    "name": docker_network_name,
-                }
-            }
+            compose_data["networks"] = {docker_network_name: {}}
+            # https://docs.docker.com/compose/compose-file/compose-file-v3/#network-configuration-reference
+            if compose_data["version"] >= "3.5":
+                compose_data["networks"][docker_network_name][
+                    "name"
+                ] = docker_network_name
 
             # prepend the netbox version to each of the service names and anything else
             # needed to make the continers unique to the netbox version
@@ -253,6 +249,10 @@ def docker_compose_file(pytestconfig, netbox_docker_repo_dirpaths):
                         "netboxcommunity/netbox:v%s" % netbox_version
                     )
 
+                if service_name == "netbox":
+                    # ensure the netbox container listens on a random port
+                    new_services[new_service_name]["ports"] = ["8080"]
+
                 # set the network and an alias to the proper short name of the container
                 # within that network
                 new_services[new_service_name]["networks"] = {
@@ -381,14 +381,10 @@ def docker_netbox_service(
     """
     netbox_integration_version = request.param
 
-    if netbox_integration_version >= version.Version("2.10"):
-        netbox_service_name = "netbox_v%s_netbox" % str(
-            netbox_integration_version
-        ).replace(".", "_")
-    else:
-        netbox_service_name = "netbox_v%s_nginx" % str(
-            netbox_integration_version
-        ).replace(".", "_")
+    netbox_service_name = "netbox_v%s_netbox" % str(netbox_integration_version).replace(
+        ".", "_"
+    )
+
     netbox_service_port = 8080
     try:
         # `port_for` takes a container port and returns the corresponding host port
