@@ -1,14 +1,8 @@
 import unittest
-
-import six
+from unittest.mock import Mock
 
 from pynetbox.core.query import Request
 
-if six.PY3:
-    from unittest.mock import Mock
-else:
-    from mock import Mock
-
 
 class RequestTestCase(unittest.TestCase):
     def test_get_openapi(self):
